@@ -8,14 +8,16 @@ except ImportError:
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.core.urlresolvers import resolve, Resolver404
+from django.core.mail import EmailMessage
 from django.db.models.loading import get_models
 from django.http import Http404
 from django.shortcuts import get_object_or_404
+from django.template import loader
 from django.utils import timezone
 from django.utils.dateparse import parse_datetime
 
 from djes.apps import indexable_registry
-import elasticsearch
+
 from elasticsearch_dsl.query import Q
 from elasticsearch_dsl import filter as es_filter
 from firebase_token_generator import create_token
@@ -26,7 +28,6 @@ from rest_framework import (
     routers
 )
 from rest_framework.decorators import detail_route, list_route
-from rest_framework.metadata import BaseMetadata
 from rest_framework.permissions import IsAdminUser
 from rest_framework.response import Response
 from rest_framework.views import APIView
@@ -42,21 +43,17 @@ from bulbs.content.serializers import (
 from bulbs.contributions.tasks import run_contributor_email_report
 from bulbs.contributions.models import Contribution
 from bulbs.contributions.serializers import ContributionSerializer, ContributorReportSerializer
+from bulbs.notifications.viewsets import NotificationViewSet
 from bulbs.special_coverage.models import SpecialCoverage
 from bulbs.special_coverage.serializers import SpecialCoverageSerializer
+from bulbs.super_features.utils import get_superfeature_model
 from bulbs.utils.methods import get_query_params, get_request_data
 
+from .metadata import PolymorphicContentMetadata
 from .mixins import UncachedResponse
 from .permissions import CanEditContent, CanPublishContent
 
 
-class ContentViewMetaData(BaseMetadata):
-    def determine_metadata(self, request, view):
-        return {
-            'status': 'ok',
-        }
-
-
 class ContentViewSet(UncachedResponse, viewsets.ModelViewSet):
     """
     uncached viewset for the `bulbs.content.Content` model
@@ -73,7 +70,7 @@ class ContentViewSet(UncachedResponse, viewsets.ModelViewSet):
         "authors", "types"
     )
     permission_classes = [IsAdminUser, CanEditContent]
-    metadata_class = ContentViewMetaData
+    metadata_class = PolymorphicContentMetadata
 
     def get_serializer_class(self):
         """gets the class type of the serializer
@@ -138,6 +135,18 @@ class ContentViewSet(UncachedResponse, viewsets.ModelViewSet):
             authors = get_query_params(self.request).getlist("authors")
             queryset = queryset.filter(Authors(authors))
 
+        if "exclude" in get_query_params(self.request):
+            exclude = get_query_params(self.request).get("exclude")
+            queryset = queryset.filter(
+                es_filter.Not(es_filter.Type(**{'value': exclude}))
+            )
+
+        # always filter out Super Features from listing page
+        queryset = queryset.filter(
+            es_filter.Not(filter=es_filter.Type(
+                value=get_superfeature_model().search_objects.mapping.doc_type))
+        )
+
         page = self.paginate_queryset(queryset)
         if page is not None:
             serializer = self.get_serializer(page, many=True)
@@ -218,23 +227,19 @@ class ContentViewSet(UncachedResponse, viewsets.ModelViewSet):
         if Contribution not in get_models():
             return Response([])
 
-        content_pk = kwargs.get('pk', None)
-        if content_pk is None:
-            return Response([], status=status.HTTP_404_NOT_FOUND)
-
-        queryset = Contribution.search_objects.search().filter(
-            es_filter.Term(**{'content.id': content_pk})
-        )
         if request.method == "POST":
-            serializer = ContributionSerializer(
-                queryset[:queryset.count()].sort('id')[:25],
-                data=get_request_data(request),
-                many=True)
+            serializer = ContributionSerializer(data=get_request_data(request), many=True)
             if not serializer.is_valid():
                 return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
             serializer.save()
             return Response(serializer.data)
         else:
+            content_pk = kwargs.get('pk', None)
+            if content_pk is None:
+                return Response([], status=status.HTTP_404_NOT_FOUND)
+            queryset = Contribution.search_objects.search().filter(
+                es_filter.Term(**{'content.id': content_pk})
+            )
             serializer = ContributionSerializer(queryset[:queryset.count()].sort('id'), many=True)
             return Response(serializer.data)
 
@@ -428,11 +433,11 @@ class MeViewSet(UncachedResponse, viewsets.ReadOnlyModelViewSet):
         if secret:
             # use firebase auth to provide auth variables to firebase security api
             firebase_auth_payload = {
-                    'id': request.user.pk,
-                    'username': request.user.username,
-                    'email': request.user.email,
-                    'is_staff': request.user.is_staff
-                    }
+                'id': request.user.pk,
+                'username': request.user.username,
+                'email': request.user.email,
+                'is_staff': request.user.is_staff
+            }
             data['firebase_token'] = create_token(secret, firebase_auth_payload)
 
         return Response(data)
@@ -454,7 +459,7 @@ class ContentTypeViewSet(viewsets.ViewSet):
                 results.append(dict(
                     name=name,
                     doctype=doctype
-                    ))
+                ))
                 results.sort(key=lambda x: x["name"])
         return Response(dict(results=results))
 
@@ -507,9 +512,17 @@ class SpecialCoverageResolveViewSet(viewsets.ReadOnlyModelViewSet):
                 active = get_query_params(self.request).get('active', '').lower()
                 now = timezone.now()
                 if active == 'true':
-                    qs = qs.filter(start_date__lte=now, end_date__gte=now)
+                    qs = qs.filter(
+                        start_date__lte=now, end_date__gte=now
+                    ) | qs.filter(
+                        start_date__lte=now, end_date__isnull=True
+                    )
                 elif active == 'false':
-                    qs = qs.exclude(start_date__lte=now, end_date__gte=now)
+                    qs = qs.exclude(
+                        start_date__lte=now, end_date__gte=now
+                    ) | qs.exclude(
+                        start_date__lte=now, end_date__isnull=False
+                    )
 
                 # Sponsored Filter
                 sponsored = get_query_params(self.request).get('sponsored', '').lower()
@@ -603,17 +616,53 @@ class SendContributorReport(viewsets.GenericViewSet):
         return Response(status=status.HTTP_200_OK)
 
 
+class ReportBugEmail(APIView):
+
+    def post(self, request):
+        SETTINGS = getattr(settings, "BUG_REPORTER", {})
+
+        report = request.DATA.get("report", "")
+        url = request.DATA.get("url", "")
+        user_agent = request.DATA.get("user_agent", "")
+
+        if request.user.first_name and request.user.last_name:
+            name = request.user.get_full_name()
+        else:
+            name = request.user.get_username()
+
+        mail = EmailMessage(
+            subject=SETTINGS.get("EMAIL_SUBJECT", "Hey! A bug was reported!"),
+            body=loader.render_to_string(
+                SETTINGS.get("EMAIL_TEMPLATE_PATH", "__bug_report_email.html"),
+                {
+                    "report": report,
+                    "url": url,
+                    "user_agent": user_agent,
+                    "submitted_by": name
+                }
+            ),
+            from_email=request.user.email,
+            to=SETTINGS.get("EMAIL_TO_ADDRESSES", ["webtech@theonion.com"])
+        )
+        mail.send()
+
+        return Response({"message": "Message Sent!"}, status=status.HTTP_200_OK)
+
+
 # api router for aforementioned/defined viewsets
 # note: me view is registered in urls.py
 api_v1_router = routers.DefaultRouter()
-api_v1_router.register(r"content", ContentViewSet, base_name="content")
-api_v1_router.register(r"custom-search-content", CustomSearchContentViewSet, base_name="custom-search-content")
-api_v1_router.register(r"content-type", ContentTypeViewSet, base_name="content-type")
-api_v1_router.register(r"content-resolve", ContentResolveViewSet, base_name="content-resolve")
-api_v1_router.register(r"special-coverage-resolve", SpecialCoverageResolveViewSet, base_name="special-coverage-resolve")
-api_v1_router.register(r"tag", TagViewSet, base_name="tag")
-api_v1_router.register(r"log", LogEntryViewSet, base_name="logentry")
 api_v1_router.register(r"author", AuthorViewSet, base_name="author")
-api_v1_router.register(r"feature-type", FeatureTypeViewSet, base_name="feature-type")
-api_v1_router.register(r"user", UserViewSet, base_name="user")
+api_v1_router.register(r"content", ContentViewSet, base_name="content")
+api_v1_router.register(r"content-resolve", ContentResolveViewSet, base_name="content-resolve")
+api_v1_router.register(r"content-type", ContentTypeViewSet, base_name="content-type")
 api_v1_router.register(r"contributor-email", SendContributorReport, base_name="contributor-email")
+api_v1_router.register(r"custom-search-content", CustomSearchContentViewSet,
+                       base_name="custom-search-content")
+api_v1_router.register(r"notification", NotificationViewSet, base_name="notification")
+api_v1_router.register(r"feature-type", FeatureTypeViewSet, base_name="feature-type")
+api_v1_router.register(r"log", LogEntryViewSet, base_name="logentry")
+api_v1_router.register(r"special-coverage-resolve", SpecialCoverageResolveViewSet,
+                       base_name="special-coverage-resolve")
+api_v1_router.register(r"tag", TagViewSet, base_name="tag")
+api_v1_router.register(r"user", UserViewSet, base_name="user")
