@@ -33,7 +33,7 @@ class Campaign(Indexable):
         :return: `bulbs.campaigns.Campaign`
         """
         campaign = super(Campaign, self).save(*args, **kwargs)
-        save_campaign_special_coverage_percolator.delay(self.id)
+        save_campaign_special_coverage_percolator.delay(self.tunic_campaign_id)
         return campaign
 
     @property
@@ -42,21 +42,3 @@ class Campaign(Indexable):
         for pixel in self.pixels.all():
             data[pixel.get_pixel_type_display()] = pixel.url
         return data
-
-
-class CampaignPixel(models.Model):
-    """Right now, there are two types of pixels, "Listing" and "Detail". The
-    intention here is that the "Listing" pixel is fired anywhere a sponsor's
-    logo shows up on a listing page, or a sidebar. The "Detail" pixel is to
-    be fired only when viewing a piece of content connected to that campaign"""
-
-    LISTING = 0
-    DETAIL = 1
-    PIXEL_TYPES = (
-        (LISTING, 'Listing'),
-        (DETAIL, 'Detail'),
-    )
-
-    campaign = models.ForeignKey(Campaign, related_name='pixels')
-    url = models.URLField()
-    pixel_type = models.IntegerField(choices=PIXEL_TYPES, default=LISTING)
