@@ -16,6 +16,6 @@ class TagCache(object):
         # Gets the count for a tag, hopefully form an in-memory cache.
         cnt = cls._cache.get(slug)
         if cnt is None:
-            cnt = Content.search_objects.query(**{"tags.slug": slug}).count()
+            cnt = Content.search_objects.search(tags=[slug]).count()
             cls._cache[slug] = cnt
         return cnt
