@@ -13,15 +13,18 @@ class BodyMixin(models.Model):
     class Meta:
         abstract = True
 
+
 class DetailImageMixin(models.Model):
     """Provides an "image" field, with caption and alt."""
     _image_caption = models.CharField(null=True, blank=True, editable=False, max_length=255)
     _image_alt = models.CharField(null=True, blank=True, editable=False, max_length=255)
-    image = ImageField(null=True, blank=True, alt_field="_image_alt", caption_field="_image_caption")
+    image = ImageField(null=True, blank=True, alt_field="_image_alt",
+                       caption_field="_image_caption")
 
     class Meta:
         abstract = True
 
+
 class ImageSerializerMixin(serializers.Serializer):
 
     image = ImageFieldSerializer(required=False, allow_null=True)
