@@ -14,7 +14,4 @@ class Command(BaseCommand):
         for model in apps.get_models(app):
             if issubclass(model, Indexable):
                 for instance in model.objects.all():
-                    try:
-                        instance.index()
-                    except:
-                        import pdb; pdb.set_trace()
+                    instance.index()
