@@ -2,36 +2,55 @@
 
 import datetime
 
+from django.http import StreamingHttpResponse
 from django.utils import dateparse, timezone
 
 from elasticsearch_dsl import filter as es_filter
 from rest_framework import viewsets, routers, mixins
 from rest_framework.settings import api_settings
-from rest_framework.response import Response
-from rest_framework_csv.renderers import CSVRenderer
 from rest_framework_nested import routers as nested_routers
 
-from bulbs.content.filters import FeatureTypes, Published, Tags
-
+from bulbs.content.filters import FeatureTypes, Tags
 
 from .filters import ESPublishedFilterBackend, StartEndFilterBackend
 from .models import (
     ContributorRole, Contribution, FeatureTypeRate, FlatRate, FreelanceProfile, HourlyRate,
     LineItem, OverrideProfile, ReportContent, MANUAL
 )
-from .renderers import ContributionReportingRenderer
-from .csv_serializers import ContributionCSVSerializer
+from .renderers import (ContributionReportingRenderer,
+                        ContentReportingRenderer,
+                        FreelanceProfileRenderer,
+                        LineItemRenderer)
+from .csv_serializers import ContributionCSVSerializer, LineItemCSVSerializer
 from .serializers import (
     ContributorRoleSerializer, ContributionReportingSerializer, ContentReportingSerializer,
     FeatureTypeRateSerializer, FlatRateSerializer, FreelanceProfileSerializer,
-    HourlyRateSerializer, LineItemSerializer, OverrideProfileSerializer
+    HourlyRateSerializer, LineEntrySerializer, OverrideProfileSerializer
 )
 from .utils import get_forced_payment_contributions
 
 
+class BaseReportViewSet(viewsets.GenericViewSet, mixins.ListModelMixin):
+
+    def list(self, request):
+        if "csv" == self.request.QUERY_PARAMS.get('format'):
+            resp = StreamingHttpResponse(request.accepted_renderer.render(
+                {'queryset': self.get_queryset(),
+                 'serializer': self.get_serializer_class(),
+                 'context': self.get_serializer_context()}),
+                content_type="text/csv",
+            )
+
+            resp['Content-Disposition'] = 'attachment; filename="{}.csv"'.format(self.csv_filename)
+
+            return resp
+        else:
+            return super(BaseReportViewSet, self).list(request)
+
+
 class LineItemViewSet(viewsets.ModelViewSet):
     queryset = LineItem.objects.all()
-    serializer_class = LineItemSerializer
+    serializer_class = LineEntrySerializer
     start_fields = ("payment_date",)
     end_fields = ("payment_date",)
     filter_backends = (StartEndFilterBackend,)
@@ -84,12 +103,14 @@ class OverrideProfileViewSet(viewsets.ModelViewSet):
     serializer_class = OverrideProfileSerializer
 
 
-class ContentReportingViewSet(viewsets.GenericViewSet, mixins.ListModelMixin):
+class ContentReportingViewSet(BaseReportViewSet):
+
+    renderer_classes = tuple(api_settings.DEFAULT_RENDERER_CLASSES) + (ContentReportingRenderer, )
 
-    renderer_classes = (CSVRenderer, ) + tuple(api_settings.DEFAULT_RENDERER_CLASSES)
     serializer_class = ContentReportingSerializer
     filter_backends = (ESPublishedFilterBackend,)
     paginate_by = 20
+    csv_filename = 'ContentReport'
 
     def get_queryset(self):
         qs = ReportContent.search_objects.search()
@@ -151,26 +172,34 @@ class ContentReportingViewSet(viewsets.GenericViewSet, mixins.ListModelMixin):
         return qs
 
 
-class ReportingViewSet(viewsets.GenericViewSet, mixins.ListModelMixin):
+class LineItemReportingViewSet(BaseReportViewSet):
 
     renderer_classes = (
-        ContributionReportingRenderer,
+        LineItemRenderer,
     ) + tuple(
         api_settings.DEFAULT_RENDERER_CLASSES
     )
+    paginate_by = 20
+    serializer_class = LineItemCSVSerializer
+    csv_filename = 'LineItemReport'
+
+    def get_queryset(self):
+        start = self.request.QUERY_PARAMS.get("start", None)
+        end = self.request.QUERY_PARAMS.get("end", None)
+        if end:
+            end = timezone.datetime.strptime(end, "%Y-%m-%d")
+            end += timezone.timedelta(days=1)
+        return LineItem.objects.filter(payment_date__range=(start, end))
+
+
+class ReportingViewSet(BaseReportViewSet):
+
+    renderer_classes = tuple(
+        api_settings.DEFAULT_RENDERER_CLASSES
+    ) + (ContributionReportingRenderer, )
     filter_backends = (ESPublishedFilterBackend,)
     paginate_by = 20
-
-    def list(self, request):
-        format = self.request.QUERY_PARAMS.get('format', None)
-        if format == 'csv':
-            queryset = self.get_queryset()
-            # TODO: get rid of this csv pattern so it incorporates the typical restful patterns.
-            queryset = ESPublishedFilterBackend().filter_queryset(request, queryset, None)
-            queryset = queryset[:queryset.count()]
-            serializer = self.get_serializer(queryset, many=True)
-            return Response(serializer.data)
-        return super(ReportingViewSet, self).list(request)
+    csv_filename = 'ContributionReport'
 
     def get_serializer_class(self):
         format = self.request.QUERY_PARAMS.get('format', None)
@@ -203,14 +232,18 @@ class ReportingViewSet(viewsets.GenericViewSet, mixins.ListModelMixin):
             qs = qs.filter(
                 es_filter.Term(**{'contributor.is_freelance': is_freelance})
             )
-        return qs.sort('id')
+
+        qs = qs.sort('id')
+
+        return ESPublishedFilterBackend().filter_queryset(self.request, qs, None)
 
 
-class FreelanceReportingViewSet(viewsets.GenericViewSet, mixins.ListModelMixin):
+class FreelanceReportingViewSet(BaseReportViewSet):
 
-    renderer_classes = (CSVRenderer, ) + tuple(api_settings.DEFAULT_RENDERER_CLASSES)
+    renderer_classes = tuple(api_settings.DEFAULT_RENDERER_CLASSES) + (FreelanceProfileRenderer, )
     serializer_class = FreelanceProfileSerializer
     paginate_by = 20
+    csv_filename = 'FreelanceReport'
 
     def get_queryset(self):
         now = timezone.now()
@@ -281,6 +314,9 @@ nested_role_router.register(
 
 api_v1_router.register(r"rate-overrides", OverrideProfileViewSet, base_name="rate-overrides")
 api_v1_router.register(r"reporting", ReportingViewSet, base_name="contributionreporting")
+api_v1_router.register(
+    r"line-item-reporting", LineItemReportingViewSet, base_name="line-item-reporting"
+)
 api_v1_router.register(r"contentreporting", ContentReportingViewSet, base_name="contentreporting")
 api_v1_router.register(
     r"freelancereporting", FreelanceReportingViewSet, base_name="freelancereporting"
