@@ -2,17 +2,18 @@ from mock import patch
 
 import contextdecorator
 
+
 class mock_vault(contextdecorator.ContextDecorator):
     """Decorator + context manager for mocking Vault secrets in unit tests.
 
     Usage:
             def test_vault(self):
-                with mock_vault({'some/secret': 'my value'}):
+                with mock_vault({'some/secret': {'my key': 'my value'}}):
                     self.assertEqual('my value', vault.read('some/secret'))
 
         .. OR ..
 
-            @mock_vault({'some/secret': 'my value'})
+            @mock_vault({'some/secret': {'my key': 'my value'}})
             def test_vault(self):
                 self.assertEqual('my value', vault.read('some/secret'))
     """
